@@ -163,9 +163,13 @@
 			else
 				$_POST['formEncoding'] = '';
 		}
+		if (!isset($_POST['formTemplate'])) $_POST['formTemplate'] = 'template1';
 		if (!isset($_POST['formSpc'])) $_POST['formSpc'] = '';
 		if (!isset($_POST['formComment'])) $_POST['formComment'] = '';
 
+		// Fetch a list of databases in the cluster
+		$templatedbs = $data->getDatabases(false);
+
 		// Fetch all tablespaces from the database
 		if ($data->hasTablespaces()) $tablespaces = $data->getTablespaces();
 
@@ -174,6 +178,28 @@
 		echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strname']}</th>\n";
 		echo "\t\t<td class=\"data1\"><input name=\"formName\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"",
 			htmlspecialchars($_POST['formName']), "\" /></td>\n\t</tr>\n";
+
+		echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strtemplatedb']}</th>\n";
+		echo "\t\t<td class=\"data1\">\n";
+		echo "\t\t\t<select name=\"formTemplate\">\n";
+		// Always offer template0 and template1 
+		echo "\t\t\t\t<option value=\"template0\"",
+			($_POST['formTemplate'] == 'template0') ? ' selected="selected"' : '', ">template0</option>\n";
+		echo "\t\t\t\t<option value=\"template1\"",
+			($_POST['formTemplate'] == 'template1') ? ' selected="selected"' : '', ">template1</option>\n";
+		while (!$templatedbs->EOF) {
+			$dbname = htmlspecialchars($templatedbs->fields['datname']);
+			if ($dbname != 'template1') { 
+				// filter out for $conf[show_system] users so we dont get duplicates 
+				echo "\t\t\t\t<option value=\"{$dbname}\"",
+					($dbname == $_POST['formTemplate']) ? ' selected="selected"' : '', ">{$dbname}</option>\n";
+			}
+			$templatedbs->moveNext();
+		}
+		echo "\t\t\t</select>\n";
+		echo "\t\t</td>\n\t</tr>\n";
+
+		// ENCODING
 		echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strencoding']}</th>\n";
 		echo "\t\t<td class=\"data1\">\n";
 		echo "\t\t\t<select name=\"formEncoding\">\n";
@@ -186,6 +212,23 @@
 		echo "\t\t\t</select>\n";
 		echo "\t\t</td>\n\t</tr>\n";
 
+		if ($data->hasDatabaseCollation()) {
+			if (!isset($_POST['formCollate'])) $_POST['formCollate'] = '';
+			if (!isset($_POST['formCType'])) $_POST['formCType'] = '';
+
+			// LC_COLLATE
+			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strcollation']}</th>\n";
+			echo "\t\t<td class=\"data1\">\n";
+			echo "\t\t\t<input name=\"formCollate\" value=\"", htmlspecialchars($_POST['formCollate']), "\" />\n";
+			echo "\t\t</td>\n\t</tr>\n";
+
+			// LC_CTYPE
+			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strctype']}</th>\n";
+			echo "\t\t<td class=\"data1\">\n";
+			echo "\t\t\t<input name=\"formCType\" value=\"", htmlspecialchars($_POST['formCType']), "\" />\n";
+			echo "\t\t</td>\n\t</tr>\n";
+		}
+
 		// Tablespace (if there are any)
 		if ($data->hasTablespaces() && $tablespaces->recordCount() > 0) {
 			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strtablespace']}</th>\n";
@@ -230,10 +273,17 @@
 		// Default comment to blank if it isn't set
 		if (!isset($_POST['formComment'])) $_POST['formComment'] = null;
 
+		// Default collate to blank if it isn't set
+		if (!isset($_POST['formCollate'])) $_POST['formCollate'] = null;
+
+		// Default ctype to blank if it isn't set
+		if (!isset($_POST['formCType'])) $_POST['formCType'] = null;
+
 		// Check that they've given a name and a definition
 		if ($_POST['formName'] == '') doCreate($lang['strdatabaseneedsname']);
 		else {
-			$status = $data->createDatabase($_POST['formName'], $_POST['formEncoding'], $_POST['formSpc'], $_POST['formComment']);
+			$status = $data->createDatabase($_POST['formName'], $_POST['formEncoding'], $_POST['formSpc'],
+				$_POST['formComment'], $_POST['formTemplate'], $_POST['formCollate'], $_POST['formCType']);
 			if ($status == 0) {
 				$_reload_browser = true;
 				doDefault($lang['strdatabasecreated']);
@@ -320,6 +370,14 @@
 				'title' => $lang['strencoding'],
 				'field' => field('datencoding'),
 			),
+			'lc_collate' => array(
+				'title' => $lang['strcollation'],
+				'field' => field('datcollate'),
+			),
+			'lc_ctype' => array(
+				'title' => $lang['strctype'],
+				'field' => field('datctype'),
+			),
 			'tablespace' => array(
 				'title' => $lang['strtablespace'],
 				'field' => field('tablespace'),
@@ -366,6 +424,7 @@
 
 		if (!$data->hasTablespaces()) unset($columns['tablespace']);
 		if (!$data->hasServerAdminFuncs()) unset($columns['dbsize']);
+		if (!$data->hasDatabaseCollation()) unset($columns['lc_collate'], $columns['lc_ctype']);
 		if (!isset($data->privlist['database'])) unset($actions['privileges']);
 
 		$misc->printTable($databases, $columns, $actions, $lang['strnodatabases']);
