@@ -11,16 +11,16 @@
 
 	// Set error reporting level to max
 	error_reporting(E_ALL);
-
+ 
 	// Application name
 	$appName = 'phpPgAdmin';
 
 	// Application version
-	$appVersion = '4.2';
+	$appVersion = '5.0.2';
 
 	// PostgreSQL and PHP minimum version
-	$postgresqlMinVer = '7.0';
-	$phpMinVer = '4.1';
+	$postgresqlMinVer = '7.4';
+	$phpMinVer = '5.0';
 
 	// Check the version of PHP
 	if (version_compare(phpversion(), $phpMinVer, '<'))
@@ -69,7 +69,6 @@
 	$misc->setForm();
 
 	// Enforce PHP environment
-	ini_set('magic_quotes_gpc', 0);
 	ini_set('magic_quotes_runtime', 0);
 	ini_set('magic_quotes_sybase', 0);
 	ini_set('arg_separator.output', '&amp;');
@@ -94,17 +93,48 @@
 		$_reload_browser = true;
 	}
 
+	/* select the theme */
+	unset($_theme);
+	$conf['theme'] = 'default';
+
+	// 1. Check for the theme from a request var
+	if (isset($_REQUEST['theme']) && is_file("./themes/{$_REQUEST['theme']}/global.css")) {
+		/* save the selected theme in cookie for a year */
+		setcookie('ppaTheme', $_REQUEST['theme'], time()+31536000);
+		$_theme = $_SESSION['ppaTheme'] = $conf['theme'] = $_REQUEST['theme'];
+	}
+
+	// 2. Check for theme session var
+	if (!isset($_theme) && isset($_SESSION['ppaTheme']) && is_file("./themes/{$_SESSION['ppaTheme']}/global.css")) {
+		$conf['theme']  = $_SESSION['ppaTheme'];
+	}
+
+	// 3. Check for theme in cookie var
+	if (!isset($_theme) && isset($_COOKIE['ppaTheme']) && is_file("./themes/{$_COOKIE['ppaTheme']}/global.css")) {
+		$conf['theme']  = $_COOKIE['ppaTheme'];
+	}
+
 	// Determine language file to import:
+	unset($_language);
+
 	// 1. Check for the language from a request var
-	if (isset($_REQUEST['language']) && isset($appLangFiles[$_REQUEST['language']]))
+	if (isset($_REQUEST['language']) && isset($appLangFiles[$_REQUEST['language']])) {
+		/* save the selected language in cookie for a year */
+		setcookie('webdbLanguage', $_REQUEST['language'], time()+31536000);
 		$_language = $_REQUEST['language'];
+	}
 
 	// 2. Check for language session var
 	if (!isset($_language) && isset($_SESSION['webdbLanguage']) && isset($appLangFiles[$_SESSION['webdbLanguage']])) {
 		$_language = $_SESSION['webdbLanguage'];
 	}
 
-	// 3. Check for acceptable languages in HTTP_ACCEPT_LANGUAGE var
+	// 3. Check for language in cookie var
+	if (!isset($_language) && isset($_COOKIE['webdbLanguage']) && isset($appLangFiles[$_COOKIE['webdbLanguage']])) {
+		$_language  = $_COOKIE['webdbLanguage'];
+	}
+
+	// 4. Check for acceptable languages in HTTP_ACCEPT_LANGUAGE var
 	if (!isset($_language) && $conf['default_lang'] == 'auto' && isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
 		// extract acceptable language tags
 		// (http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)
@@ -126,7 +156,7 @@
 		}
 	}
 
-	// 4. Otherwise resort to the default set in the config file
+	// 5. Otherwise resort to the default set in the config file
 	if (!isset($_language) && $conf['default_lang'] != 'auto' && isset($appLangFiles[$conf['default_lang']])) {
 		$_language = $conf['default_lang'];
 	}
@@ -152,11 +182,15 @@
 	// Create data accessor object, if necessary
 	if (!isset($_no_db_connection)) {
 		if (!isset($_REQUEST['server'])) {
-                        echo $lang['strnoserversupplied'];
-                        exit;
-	        }
+			echo $lang['strnoserversupplied'];
+			exit;
+	    }
 		$_server_info = $misc->getServerInfo();
 
+		/* starting with PostgreSQL 9.0, we can set the application name */
+		if(isset($_server_info['pgVersion']) && $_server_info['pgVersion'] >= 9)
+			putenv("PGAPPNAME={$appName}_{$appVersion}");
+
 		// Redirect to the login form if not logged in
 		if (!isset($_server_info['username'])) {
 			include('./login.php');
@@ -177,7 +211,7 @@
 
 		// If schema is defined and database supports schemas, then set the
 		// schema explicitly.
-		if (isset($_REQUEST['database']) && isset($_REQUEST['schema']) && $data->hasSchemas()) {
+		if (isset($_REQUEST['database']) && isset($_REQUEST['schema'])) {
 			$status = $data->setSchema($_REQUEST['schema']);
 			if ($status != 0) {
 				echo $lang['strbadschema'];
