@@ -76,10 +76,10 @@
 			echo "<tr><th class=\"data left required\">{$lang['strname']}</th>\n";
 			echo "<td class=\"data1\">";
 			echo "<input name=\"name\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"",
-				htmlspecialchars($_POST['name']), "\" /></td></tr>\n";
+				htmlspecialchars($_POST['name'], ENT_QUOTES), "\" /></td></tr>\n";
 
 			$server_info = $misc->getServerInfo();
-			if ($data->hasAlterTableOwner() && $data->isSuperUser($server_info['username'])) {
+			if ($data->isSuperUser($server_info['username'])) {
 				echo "<tr><th class=\"data left required\">{$lang['strowner']}</th>\n";
 				echo "<td class=\"data1\"><select name=\"owner\">";
 				while (!$users->EOF) {
@@ -270,7 +270,7 @@
 				echo "<table>\n";
 				echo "<tr><th class=\"data required\">{$lang['strname']}</th>\n<th colspan=\"2\" class=\"data required\">{$lang['strtype']}</th>\n";
 				echo "<th class=\"data\">{$lang['strlength']}</th>\n";
-				if ($data->hasAlterColumnType())
+				if ($data->hasCreateFieldWithConstraints())
 					echo "<th class=\"data\">{$lang['strnotnull']}</th>\n<th class=\"data\">{$lang['strdefault']}</th>\n";
 				echo "<th class=\"data\">{$lang['strcomment']}</th></tr>\n";
 
@@ -278,7 +278,7 @@
 					htmlspecialchars($_POST['field']), "\" /></td>\n";
 				echo "<td><select name=\"type\" id=\"type\" onchange=\"checkLengths(document.getElementById('type').value,'');\">\n";
 				// Output any "magic" types.  This came in with the alter column type so we'll check that
-				if ($data->hasAlterColumnType()) {
+				if ($data->hasMagicTypes()) {
 					foreach ($data->extraTypes as $v) {
 						$types_for_js[] = strtolower($v);
 						echo "\t<option value=\"", htmlspecialchars($v), "\"",
@@ -309,7 +309,7 @@
 				echo "<td><input name=\"length\" id=\"lengths\" size=\"8\" value=\"",
 					htmlspecialchars($_POST['length']), "\" /></td>\n";
 				// Support for adding column with not null and default
-				if ($data->hasAlterColumnType()) {
+				if ($data->hasCreateFieldWithConstraints()) {
 					echo "<td><input type=\"checkbox\" name=\"notnull\"",
 						(isset($_REQUEST['notnull'])) ? ' checked="checked"' : '', " /></td>\n";
 					echo "<td><input name=\"default\" size=\"20\" value=\"",
@@ -321,8 +321,8 @@
 				echo "<p><input type=\"hidden\" name=\"action\" value=\"add_column\" />\n";
 				echo "<input type=\"hidden\" name=\"stage\" value=\"2\" />\n";
 				echo $misc->form;
-				echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\">\n";
-				if (!$data->hasAlterColumnType()) {
+				echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
+				if (!$data->hasCreateFieldWithConstraints()) {
 					echo "<input type=\"hidden\" name=\"default\" value=\"\" />\n";
 				}
 				echo "<input type=\"submit\" value=\"{$lang['stradd']}\" />\n";
@@ -376,10 +376,7 @@
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"column\" value=\"", htmlspecialchars($_REQUEST['column']), "\" />\n";
 			echo $misc->form;
-			// Show cascade drop option if supportd
-			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\"> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
-			}
+			echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\"> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
 			echo "</form>\n";
@@ -446,7 +443,13 @@
 		function attPre(&$rowdata, $actions) {
 			global $data;
 			$rowdata->fields['+type'] = $data->formatType($rowdata->fields['type'], $rowdata->fields['atttypmod']);
-			$actions['browse']['url'] .= 'query=' . urlencode("SELECT \"{$rowdata->fields['attname']}\", count(*) AS \"count\" FROM \"{$_REQUEST['table']}\" GROUP BY \"{$rowdata->fields['attname']}\" ORDER BY \"{$rowdata->fields['attname']}\"") . '&amp;';
+			$attname = $rowdata->fields['attname'];
+			$table = $_REQUEST['table'];
+			$data->fieldClean($attname);
+			$data->fieldClean($table);
+
+			$actions['browse']['url'] .= 'query=' . urlencode("SELECT \"{$attname}\", count(*) AS \"count\"
+				FROM \"{$table}\" GROUP BY \"{$attname}\" ORDER BY \"{$attname}\"") . '&amp;';
 			return $actions;
 		}
 
@@ -458,6 +461,8 @@
 		$tdata = $data->getTable($_REQUEST['table']);
 		// Get columns
 		$attrs = $data->getTableAttributes($_REQUEST['table']);
+		// Get constraints keys
+		$ck = $data->getConstraintsWithFields($_REQUEST['table']);
 
 		// Show comment if any
 		if ($tdata->fields['relcomment'] !== null)
@@ -484,7 +489,15 @@
 				'title' => $lang['strdefault'],
 				'field' => field('adsrc'),
 			),
-			'keyprop' => 1,
+			'keyprop' => array(
+				'title' => $lang['strconstraints'],
+				'field' => field('attname'),
+				'type'  => 'callback',
+				'params'=> array(
+					'function' => 'cstrRender',
+					'keys' => $ck->getArray()
+				)
+			),
 			'actions' => array(
 				'title' => $lang['stractions'],
 			),
@@ -494,58 +507,41 @@
 			),
 		);
 
-		if (!$data->hasConstraintsInfo()) {
-			unset($columns['keyprop']);
-		}
-		else {
-			$ck = $data->getConstraintsWithFields($_REQUEST['table']);
+		function cstrRender($s, $p) {
+			global $misc, $data;
 
-			$columns['keyprop'] = array(
-				'title' => $lang['strconstraints'],
-				'field' => field('attname'),
-				'type'  => 'callback',
-				'params'=> array(
-					'function' => 'cstrRender',
-					'keys' => $ck->getArray()
-      	),
-			);
+			$str ='';
+			foreach ($p['keys'] as $k => $c) {
 
-			function cstrRender($s, $p) {
-				global $misc, $data;
-
-				$str ='';
-				foreach ($p['keys'] as $k => $c) {
-
-					if (is_null($p['keys'][$k]['consrc'])) {
-						$atts = $data->getAttributeNames($_REQUEST['table'], explode(' ', $p['keys'][$k]['indkey']));
-						$c['consrc'] = ($c['contype'] == 'u' ? "UNIQUE (" : "PRIMARY KEY (") . join(',', $atts) . ')';
-					}
-
-					if ($c['p_field'] == $s)
-						switch ($c['contype']) {
-							case 'p':
-							    $str .= '<a href="constraints.php?'. $misc->href ."&amp;table={$c['p_table']}&amp;schema={$c['p_schema']}\"><img src=\"".
-									$misc->icon('PrimaryKey') .'" alt="[pk]" title="'. htmlentities($c['consrc']) .'" /></a>';
-							break;
-							case 'f':
-								$str .= '<a href="tblproperties.php?'. $misc->href ."&amp;table={$c['f_table']}&amp;schema={$c['f_schema']}\"><img src=\"".
-									$misc->icon('ForeignKey') .'" alt="[fk]" title="'. htmlentities($c['consrc']) .'" /></a>';
-							break;
-							case 'u':
-								$str .= '<a href="constraints.php?'. $misc->href ."&amp;table={$c['p_table']}&amp;schema={$c['p_schema']}\"><img src=\"".
-									$misc->icon('UniqueConstraint') .'" alt="[uniq]" title="'. htmlentities($c['consrc']) .'" /></a>';
-							break;
-							case 'c':
-								$str .= '<a href="constraints.php?'. $misc->href ."&amp;table={$c['p_table']}&amp;schema={$c['p_schema']}\"><img src=\"".
-									$misc->icon('CheckConstraint') .'" alt="[check]" title="'. htmlentities($c['consrc']) .'" /></a>';
-						}
+				if (is_null($p['keys'][$k]['consrc'])) {
+					$atts = $data->getAttributeNames($_REQUEST['table'], explode(' ', $p['keys'][$k]['indkey']));
+					$c['consrc'] = ($c['contype'] == 'u' ? "UNIQUE (" : "PRIMARY KEY (") . join(',', $atts) . ')';
 				}
 
-				return $str;
+				if ($c['p_field'] == $s)
+					switch ($c['contype']) {
+						case 'p':
+							$str .= '<a href="constraints.php?'. $misc->href ."&amp;table=". urlencode($c['p_table']) ."&amp;schema=". urlencode($c['p_schema']) ."\"><img src=\"".
+								$misc->icon('PrimaryKey') .'" alt="[pk]" title="'. htmlentities($c['consrc']) .'" /></a>';
+						break;
+						case 'f':
+							$str .= '<a href="tblproperties.php?'. $misc->href ."&amp;table=". urlencode($c['f_table']) ."&amp;schema=". urlencode($c['f_schema']) ."\"><img src=\"".
+								$misc->icon('ForeignKey') .'" alt="[fk]" title="'. htmlentities($c['consrc']) .'" /></a>';
+						break;
+						case 'u':
+							$str .= '<a href="constraints.php?'. $misc->href ."&amp;table=". urlencode($c['p_table']) ."&amp;schema=". urlencode($c['p_schema']) ."\"><img src=\"".
+								$misc->icon('UniqueConstraint') .'" alt="[uniq]" title="'. htmlentities($c['consrc']) .'" /></a>';
+						break;
+						case 'c':
+							$str .= '<a href="constraints.php?'. $misc->href ."&amp;table=". urlencode($c['p_table']) ."&amp;schema=". urlencode($c['p_schema']) ."\"><img src=\"".
+								$misc->icon('CheckConstraint') .'" alt="[check]" title="'. htmlentities($c['consrc']) .'" /></a>';
+					}
 			}
+
+			return $str;
 		}
 
-		$return_url = urlencode("tblproperties.php?{$misc->href}&amp;table={$_REQUEST['table']}");
+		$return_url = urlencode("tblproperties.php?{$misc->href}&amp;table=". urlencode($_REQUEST['table']));
 
 		$actions = array(
 			'browse' => array(
@@ -558,6 +554,11 @@
 				'url'   => "colproperties.php?action=properties&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
 				'vars'  => array('column' => 'attname'),
 			),
+			'privileges' => array(
+				'title' => $lang['strprivileges'],
+				'url'   => "privileges.php?subject=column&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
+				'vars'  => array('column' => 'attname'),
+			),
 			'drop' => array(
 				'title' => $lang['strdrop'],
 				'url'   => "tblproperties.php?action=confirm_drop&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
@@ -565,8 +566,6 @@
 			),
 		);
 
-		if (!$data->hasDropColumn()) unset($actions['drop']);
-
 		$misc->printTable($attrs, $columns, $actions, null, 'attPre');
 
 		echo "<ul class=\"navlink\">\n";
