@@ -79,10 +79,7 @@
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"trigger\" value=\"", htmlspecialchars($_REQUEST['trigger']), "\" />\n";
 			echo $misc->form;
-			// Show cascade drop option if supportd
-			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
-			}
+			echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			echo "<input type=\"submit\" name=\"yes\" value=\"{$lang['stryes']}\" />\n";
 			echo "<input type=\"submit\" name=\"no\" value=\"{$lang['strno']}\" />\n";
 			echo "</form>\n";
@@ -200,7 +197,7 @@
 		$sel3 = new XHTML_Select('formFrequency');
 		$sel3->set_data($data->triggerFrequency);
 		
-		echo "<form action=\"triggers.php\" method=\"POST\">\n";
+		echo "<form action=\"triggers.php\" method=\"post\">\n";
 		echo "<table>\n";
 		echo "<tr>\n";
 		echo "		<th class=\"data\">{$lang['strname']}</th>\n";
@@ -314,7 +311,6 @@
 				'vars'  => array('trigger' => 'tgname'),
 			),
 		);
-		if(!$data->hasSchemas()) unset($columns['function']['vars']['schema']);
 		if($data->hasDisableTriggers()) {
 			if(!$data->phpBool($triggers->fields["tgenabled"])) {
 				$actions['enable'] = array(
@@ -331,8 +327,6 @@
 			}
 		}
 
-		if (!$data->hasAlterTrigger()) unset($actions['alter']);
-
 		$misc->printTable($triggers, $columns, $actions, $lang['strnotriggers'], 'tgPre');
 		
 		echo "<p><a class=\"navlink\" href=\"triggers.php?action=create&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']), "\">{$lang['strcreatetrigger']}</a></p>\n";
